bayespy.inference.vmp.nodes.stochastic.Stochastic.move_plates
=============================================================

.. currentmodule:: bayespy.inference.vmp.nodes.stochastic

.. automethod:: Stochastic.move_plates